# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/live/general/interfaces/v1/interfaces.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4bilibili/live/general/interfaces/v1/interfaces.proto\x12#bilibili.live.general.interfaces.v1\"d\n\x10GetOnlineRankReq\x12\x0c\n\x04ruid\x18\x01 \x01(\x03\x12\x0f\n\x07room_id\x18\x02 \x01(\x03\x12\x0c\n\x04page\x18\x03 \x01(\x03\x12\x11\n\tpage_size\x18\x04 \x01(\x03\x12\x10\n\x08platform\x18\x05 \x01(\t\"\xaa\x02\n\x11GetOnlineRankResp\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.bilibili.live.general.interfaces.v1.GetOnlineRankResp.OnlineRankItem\x12\x12\n\nonline_num\x18\x02 \x01(\x03\x1a\xab\x01\n\x0eOnlineRankItem\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\r\n\x05uname\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x16\n\x0e\x63ontinue_watch\x18\x04 \x01(\x03\x12\x42\n\nmedal_info\x18\x05 \x01(\x0b\x32..bilibili.live.general.interfaces.v1.MedalInfo\x12\x13\n\x0bguard_level\x18\x06 \x01(\x03\"\xb8\x01\n\tMedalInfo\x12\x13\n\x0bguard_level\x18\x01 \x01(\x03\x12\x19\n\x11medal_color_start\x18\x02 \x01(\x03\x12\x17\n\x0fmedal_color_end\x18\x03 \x01(\x03\x12\x1a\n\x12medal_color_border\x18\x04 \x01(\x03\x12\x12\n\nmedal_name\x18\x05 \x01(\t\x12\r\n\x05level\x18\x06 \x01(\x03\x12\x11\n\ttarget_id\x18\x07 \x01(\x03\x12\x10\n\x08is_light\x18\x08 \x01(\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.live.general.interfaces.v1.interfaces_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETONLINERANKREQ']._serialized_start=93
  _globals['_GETONLINERANKREQ']._serialized_end=193
  _globals['_GETONLINERANKRESP']._serialized_start=196
  _globals['_GETONLINERANKRESP']._serialized_end=494
  _globals['_GETONLINERANKRESP_ONLINERANKITEM']._serialized_start=323
  _globals['_GETONLINERANKRESP_ONLINERANKITEM']._serialized_end=494
  _globals['_MEDALINFO']._serialized_start=497
  _globals['_MEDALINFO']._serialized_end=681
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/distribution/setting/privacy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.distribution.v1 import distribution_pb2 as bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/bilibili/app/distribution/setting/privacy.proto\x12)bilibili.app.distribution.setting.privacy\x1a/bilibili/app/distribution/v1/distribution.proto\"_\n\x18MidPrivacySettingsConfig\x12\x43\n\x12recommend_to_known\x18\x01 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\"\x9c\x01\n\x15PrivacySettingsConfig\x12\x43\n\x12\x61\x64_recommand_store\x18\x01 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12>\n\rsensor_access\x18\x02 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.distribution.setting.privacy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MIDPRIVACYSETTINGSCONFIG']._serialized_start=143
  _globals['_MIDPRIVACYSETTINGSCONFIG']._serialized_end=238
  _globals['_PRIVACYSETTINGSCONFIG']._serialized_start=241
  _globals['_PRIVACYSETTINGSCONFIG']._serialized_end=397
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/render/render.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x62ilibili/render/render.proto\x12\x0f\x62ilibili.render\x1a\x19google/protobuf/any.proto\"X\n\x06Render\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0b\n\x03ttl\x18\x03 \x01(\t\x12\"\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Anyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.render.render_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RENDER']._serialized_start=76
  _globals['_RENDER']._serialized_end=164
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pgc/biz/room.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12pgc/biz/room.proto\x12\x07pgc.biz\"\x1c\n\tRoomProto\x12\x0f\n\x07room_id\x18\x01 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pgc.biz.room_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ROOMPROTO']._serialized_start=31
  _globals['_ROOMPROTO']._serialized_end=59
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/metadata/restriction/restriction.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/bilibili/metadata/restriction/restriction.proto\x12\x1d\x62ilibili.metadata.restriction\"\x98\x01\n\x0bRestriction\x12\x16\n\x0eteenagers_mode\x18\x01 \x01(\x08\x12\x14\n\x0clessons_mode\x18\x02 \x01(\x08\x12\x35\n\x04mode\x18\x03 \x01(\x0e\x32\'.bilibili.metadata.restriction.ModeType\x12\x0e\n\x06review\x18\x04 \x01(\x08\x12\x14\n\x0c\x64isable_rcmd\x18\x05 \x01(\x08*2\n\x08ModeType\x12\n\n\x06NORMAL\x10\x00\x12\r\n\tTEENAGERS\x10\x01\x12\x0b\n\x07LESSONS\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.metadata.restriction.restriction_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MODETYPE']._serialized_start=237
  _globals['_MODETYPE']._serialized_end=287
  _globals['_RESTRICTION']._serialized_start=83
  _globals['_RESTRICTION']._serialized_end=235
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/card/v1/single.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.card.v1 import common_pb2 as bilibili_dot_app_dot_card_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!bilibili/app/card/v1/single.proto\x12\x14\x62ilibili.app.card.v1\x1a!bilibili/app/card/v1/common.proto\"\xbc\x04\n\x0cSmallCoverV5\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x11\n\tcover_gif\x18\x02 \x01(\t\x12$\n\x02up\x18\x03 \x01(\x0b\x32\x18.bilibili.app.card.v1.Up\x12\x1a\n\x12\x63over_right_text_1\x18\x04 \x01(\t\x12\x14\n\x0cright_desc_1\x18\x05 \x01(\t\x12\x14\n\x0cright_desc_2\x18\x06 \x01(\t\x12<\n\x11rcmd_reason_style\x18\x07 \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12?\n\x10hotword_entrance\x18\x08 \x01(\x0b\x32%.bilibili.app.card.v1.HotwordEntrance\x12<\n\x11\x63orner_mark_style\x18\t \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12\x14\n\x0cright_icon_1\x18\n \x01(\x05\x12\x14\n\x0cright_icon_2\x18\x0b \x01(\x05\x12\x41\n\x16left_corner_mark_style\x18\x0c \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12,\n$cover_right_text_content_description\x18\r \x01(\t\x12\'\n\x1fright_desc1_content_description\x18\x0e \x01(\t\"\xb9\x04\n\x0eSmallCoverV5Ad\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x11\n\tcover_gif\x18\x02 \x01(\t\x12$\n\x02up\x18\x03 \x01(\x0b\x32\x18.bilibili.app.card.v1.Up\x12\x19\n\x11\x63over_right_text1\x18\x04 \x01(\t\x12\x13\n\x0bright_desc1\x18\x05 \x01(\t\x12\x13\n\x0bright_desc2\x18\x06 \x01(\t\x12<\n\x11rcmd_reason_style\x18\x07 \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12?\n\x10hotword_entrance\x18\x08 \x01(\x0b\x32%.bilibili.app.card.v1.HotwordEntrance\x12<\n\x11\x63orner_mark_style\x18\t \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12\x13\n\x0bright_icon1\x18\n \x01(\x05\x12\x13\n\x0bright_icon2\x18\x0b \x01(\x05\x12\x41\n\x16left_corner_mark_style\x18\x0c \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12,\n$cover_right_text_content_description\x18\r \x01(\t\x12\'\n\x1fright_desc1_content_description\x18\x0e \x01(\t\"U\n\x0fHotwordEntrance\x12\x12\n\nhotword_id\x18\x01 \x01(\x03\x12\x10\n\x08hot_text\x18\x02 \x01(\t\x12\x0e\n\x06h5_url\x18\x03 \x01(\t\x12\x0c\n\x04icon\x18\x04 \x01(\t\"\x9d\x06\n\x0cLargeCoverV1\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x11\n\tcover_gif\x18\x02 \x01(\t\x12,\n\x06\x61vatar\x18\x03 \x01(\x0b\x32\x1c.bilibili.app.card.v1.Avatar\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x06 \x01(\t\x12\x13\n\x0b\x63over_badge\x18\x07 \x01(\t\x12\x17\n\x0ftop_rcmd_reason\x18\x08 \x01(\t\x12\x1a\n\x12\x62ottom_rcmd_reason\x18\t \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\n \x01(\t\x12\x15\n\rofficial_icon\x18\x0b \x01(\x05\x12\x10\n\x08\x63\x61n_play\x18\x0c \x01(\x05\x12@\n\x15top_rcmd_reason_style\x18\r \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12\x43\n\x18\x62ottom_rcmd_reason_style\x18\x0e \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12?\n\x14rcmd_reason_style_v2\x18\x0f \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12\x41\n\x16left_cover_badge_style\x18\x10 \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12\x42\n\x17right_cover_badge_style\x18\x11 \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12\x15\n\rcover_badge_2\x18\x12 \x01(\t\x12\x35\n\x0blike_button\x18\x13 \x01(\x0b\x32 .bilibili.app.card.v1.LikeButton\x12\x19\n\x11title_single_line\x18\x14 \x01(\x05\x12\x18\n\x10\x63over_right_text\x18\x15 \x01(\t\"\xb0\x01\n\x0eThreeItemAllV2\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12@\n\x15top_rcmd_reason_style\x18\x02 \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12\x32\n\x04item\x18\x03 \x03(\x0b\x32$.bilibili.app.card.v1.TwoItemHV1Item\"\xd2\x01\n\x0eTwoItemHV1Item\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\r\n\x05param\x18\x04 \x01(\t\x12(\n\x04\x61rgs\x18\x05 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Args\x12\x0c\n\x04goto\x18\x06 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x07 \x01(\t\x12\x19\n\x11\x63over_left_icon_1\x18\x08 \x01(\x05\x12\x18\n\x10\x63over_right_text\x18\t \x01(\t\"\xae\x01\n\x0bRcmdOneItem\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12=\n\x12topRcmdReasonStyle\x18\x02 \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12\x36\n\x04item\x18\x03 \x01(\x0b\x32(.bilibili.app.card.v1.SmallCoverRcmdItem\"\xae\x02\n\x12SmallCoverRcmdItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\r\n\x05param\x18\x04 \x01(\t\x12\x0c\n\x04goto\x18\x05 \x01(\t\x12\x17\n\x0f\x63overRightText1\x18\x06 \x01(\t\x12\x12\n\nrightDesc1\x18\x07 \x01(\t\x12\x12\n\nrightDesc2\x18\x08 \x01(\t\x12\x10\n\x08\x63overGif\x18\t \x01(\t\x12\x12\n\nrightIcon1\x18\n \x01(\x05\x12\x12\n\nrightIcon2\x18\x0b \x01(\x05\x12,\n$cover_right_text_content_description\x18\x0c \x01(\t\x12\'\n\x1fright_desc1_content_description\x18\r \x01(\t\"\xa3\x01\n\x0bThreeItemV1\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x11\n\ttitleIcon\x18\x02 \x01(\x05\x12\x0f\n\x07moreUri\x18\x03 \x01(\t\x12\x10\n\x08moreText\x18\x04 \x01(\t\x12\x34\n\x05items\x18\x05 \x03(\x0b\x32%.bilibili.app.card.v1.ThreeItemV1Item\"\x96\x01\n\x0fThreeItemV1Item\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x15\n\rcoverLeftText\x18\x02 \x01(\t\x12\x15\n\rcoverLeftIcon\x18\x03 \x01(\x05\x12\r\n\x05\x64\x65sc1\x18\x04 \x01(\t\x12\r\n\x05\x64\x65sc2\x18\x05 \x01(\t\x12\r\n\x05\x62\x61\x64ge\x18\x06 \x01(\t\"G\n\x0cHotTopicItem\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05param\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"u\n\x08HotTopic\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x31\n\x05items\x18\x03 \x03(\x0b\x32\".bilibili.app.card.v1.HotTopicItem\"\xfd\x01\n\nDynamicHot\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x16\n\x0etop_left_title\x18\x02 \x01(\t\x12\r\n\x05\x64\x65sc1\x18\x03 \x01(\t\x12\r\n\x05\x64\x65sc2\x18\x04 \x01(\t\x12\x10\n\x08more_uri\x18\x05 \x01(\t\x12\x11\n\tmore_text\x18\x06 \x01(\t\x12\x0e\n\x06\x63overs\x18\x07 \x03(\t\x12\x18\n\x10\x63over_right_text\x18\x08 \x01(\t\x12@\n\x15top_rcmd_reason_style\x18\t \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\"\x95\x01\n\rMiddleCoverV3\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\r\n\x05\x64\x65sc1\x18\x02 \x01(\t\x12\r\n\x05\x64\x65sc2\x18\x03 \x01(\t\x12<\n\x11\x63over_badge_style\x18\x04 \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\"\xb8\x02\n\x0cLargeCoverV4\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x19\n\x11\x63over_left_text_1\x18\x02 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x04 \x01(\t\x12\x13\n\x0b\x63over_badge\x18\x05 \x01(\t\x12\x10\n\x08\x63\x61n_play\x18\x06 \x01(\x05\x12$\n\x02up\x18\x07 \x01(\x0b\x32\x18.bilibili.app.card.v1.Up\x12\x12\n\nshort_link\x18\x08 \x01(\t\x12\x16\n\x0eshare_subtitle\x18\t \x01(\t\x12\x13\n\x0bplay_number\x18\n \x01(\t\x12\x0c\n\x04\x62vid\x18\x0b \x01(\t\x12\x11\n\tsub_param\x18\x0c \x01(\t\"q\n\x12PopularTopEntrance\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x31\n\x05items\x18\x02 \x03(\x0b\x32\".bilibili.app.card.v1.EntranceItem\"\xb3\x01\n\x0c\x45ntranceItem\x12\x0c\n\x04goto\x18\x01 \x01(\t\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x11\n\tmodule_id\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\x13\n\x0b\x65ntrance_id\x18\x06 \x01(\x03\x12,\n\x06\x62ubble\x18\x07 \x01(\x0b\x32\x1c.bilibili.app.card.v1.Bubble\x12\x15\n\rentrance_type\x18\x08 \x01(\x05\"@\n\x06\x42ubble\x12\x16\n\x0e\x62ubble_content\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\r\n\x05stime\x18\x03 \x01(\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.card.v1.single_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SMALLCOVERV5']._serialized_start=95
  _globals['_SMALLCOVERV5']._serialized_end=667
  _globals['_SMALLCOVERV5AD']._serialized_start=670
  _globals['_SMALLCOVERV5AD']._serialized_end=1239
  _globals['_HOTWORDENTRANCE']._serialized_start=1241
  _globals['_HOTWORDENTRANCE']._serialized_end=1326
  _globals['_LARGECOVERV1']._serialized_start=1329
  _globals['_LARGECOVERV1']._serialized_end=2126
  _globals['_THREEITEMALLV2']._serialized_start=2129
  _globals['_THREEITEMALLV2']._serialized_end=2305
  _globals['_TWOITEMHV1ITEM']._serialized_start=2308
  _globals['_TWOITEMHV1ITEM']._serialized_end=2518
  _globals['_RCMDONEITEM']._serialized_start=2521
  _globals['_RCMDONEITEM']._serialized_end=2695
  _globals['_SMALLCOVERRCMDITEM']._serialized_start=2698
  _globals['_SMALLCOVERRCMDITEM']._serialized_end=3000
  _globals['_THREEITEMV1']._serialized_start=3003
  _globals['_THREEITEMV1']._serialized_end=3166
  _globals['_THREEITEMV1ITEM']._serialized_start=3169
  _globals['_THREEITEMV1ITEM']._serialized_end=3319
  _globals['_HOTTOPICITEM']._serialized_start=3321
  _globals['_HOTTOPICITEM']._serialized_end=3392
  _globals['_HOTTOPIC']._serialized_start=3394
  _globals['_HOTTOPIC']._serialized_end=3511
  _globals['_DYNAMICHOT']._serialized_start=3514
  _globals['_DYNAMICHOT']._serialized_end=3767
  _globals['_MIDDLECOVERV3']._serialized_start=3770
  _globals['_MIDDLECOVERV3']._serialized_end=3919
  _globals['_LARGECOVERV4']._serialized_start=3922
  _globals['_LARGECOVERV4']._serialized_end=4234
  _globals['_POPULARTOPENTRANCE']._serialized_start=4236
  _globals['_POPULARTOPENTRANCE']._serialized_end=4349
  _globals['_ENTRANCEITEM']._serialized_start=4352
  _globals['_ENTRANCEITEM']._serialized_end=4531
  _globals['_BUBBLE']._serialized_start=4533
  _globals['_BUBBLE']._serialized_end=4597
# @@protoc_insertion_point(module_scope)
